@@ -24,5 +24,24 @@ if (.runThisTest) {
         checkException(a$addItem(-2, v), msg="check negative index", silent=TRUE)
         checkException(a$addItem(NA, v), msg="check NA index", silent=TRUE)
     }
-    
+
+    test03getItemsVectors <- function() {
+        ## modeled after annoy_test.py() and its t
+        i <- new(AnnoyAngular, 10)
+        i$load(system.file("tests", "data", "test.tree", package="RcppAnnoy"))
+
+        u <- i$getItemsVector(99)
+        i$save(tempfile())
+
+        v <- i$getItemsVector(99)
+        checkEquals(u, v, msg="getItemVector comparison")
+
+        j <- new(AnnoyAngular, 10)
+        j$load(system.file("tests", "data", "test.tree", package="RcppAnnoy"))
+
+        w <- i$getItemsVector(99)
+        checkEquals(u, w, msg="getItemVector comparison")
+    }
+
+
 }
